#!/usr/bin/python
#-*- coding=utf-8 -*-
#
# Author: Shizhengxian
# DateTime: Tues, Jun 03 2014 09:09:32
#
# M_Time: Sun, Jun 15 2014 09:51:24 
# Modify: 1. 修改了alter_log（软件更新）输出的time最后一个字符为“：”的格式错误.
#       : 2. 修改Xorg信息中有的加载时间格式错误，如“RADEON：……”的bug.
#       : 3. 修改软件包安装情况中软件包中的信息大都存在“<none>”的内容.
#       : 4. 修改msg为显示为空的缺陷.
#
# M_Time: Mon, Jun 16 2014 11:13:42 
# Modify: 1. 添加过滤boot_log日志文件中修饰颜色的字符串串.
#       : 2. 修改登录失败次数为0时，为不显示任何时间，之前显示1970-01-01从感觉上不对.
#       : 3. 月份基本上全部显示为数值表示.
#

import os
import sys
import re

#-- 导入Gen_Inter类 --#
sys.path.append( r'.');
from Gen_Inter import Gen_Inter


class Parser_LPMT:
    #----------------------------------------------------------------#
    #-@brief: 解析单个boot日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 boot.*log* 的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_boot_log( self, path_name) :
        '''返回值为[{"doit":None, "msg":None},{...}]列表'''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            for log_line in log_stream:
                #-- 初始化子字典的key:value--#
                item_dict = {};

                doit = "";  #-- 动作     --#
                msg  = "";  #-- 描述信息 --#

                #-- 为空行继续读下一行 --#
                if len( log_line.strip()) == 0 :
                    continue;

                log_line = log_line.replace( '\r', ' ');

                #-- 去除修饰颜色的字符串 --#
                color_left_i = log_line.find( '\x1b');
                while color_left_i != -1 :
                    color_right_i = log_line.find( 'G', color_left_i);
                    if color_right_i != -1 :
                        #-- 去除颜色描述字符'\x1b[xxxG'这样的字符串 --#
                        color_str = log_line[ color_left_i : (color_right_i + 1)];
                        log_line  = log_line.replace( color_str, ' ');
                    else :
                        #-- 去除颜色描述字符'\x1b[xx;xxm'这样的字符串 --#
                        color_right_i = log_line.find( 'm', color_left_i);
                        if color_right_i != -1 :
                            color_str = log_line[ color_left_i : (color_right_i + 1)];
                            log_line  = log_line.replace( color_str, ' ');

                    #-- 查找下一个颜色修复字符串 --#
                    color_left_i = log_line.find( '\x1b');

                #-- 拆分字符串变量，获取动作和描述信息 --#
                tmp_list = log_line.strip().split();
                tmp_str  = str( tmp_list[0]).strip();

                if '*' == tmp_str :
                    #-- 为*号开头，一般后面会跟随具体动作，接着是描述信息 --#
                    item_2nd_len = len( str( tmp_list[1]));

                    item_dict[ 'doit'] = str( tmp_list[1]).strip();
                    item_dict[ 'msg' ] = log_line[ (3 + item_2nd_len) : ].strip();
                elif 'Turning' == tmp_str :
                    #-- Turning 后后面通常加个修饰单词 --#
                    item_dict[ 'doit'] = tmp_str + ' ' +  str( tmp_list[1]).strip();
                    item_dict[ 'msg' ] = log_line.strip();
                else :
                    #-- 其他执行的命令信息 --#
                    if ':' == tmp_str[-1] :
                        item_dict[ 'doit'] = tmp_str[ 0 : -1];
                    else :
                        item_dict[ 'doit'] = tmp_str;
                    item_dict[ 'msg' ] = log_line[ len( tmp_str) : ].strip();

                #-- 有数据才会插入队列中 --#
                if len( item_dict) :
                    root_list.append( item_dict);

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg') == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "boot_log"');

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_boot_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个kern日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 kern.*log* 的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_kern_log( self, path_name) :
        '''返回值为[{"date":None, "time":None, "user":None", "msg":None},{...}]列表'''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            for log_line in log_stream:
                item_dict = {};

                date = "";  #-- 日期     --#
                time = "";  #-- 时间     --#
                user = "";  #-- 用户名   --#
                doit = "";  #-- 动作     --#
                msg  = "";  #-- 描述信息 --#

                #-- 临时字符串变量，用户计算上述4个元素项值 --#
                tmp_str = log_line.strip();

                #-- 为空行继续读下一行 --#
                if len( tmp_str) == 0 :
                    continue;

                #-- 月份模式 --#
                mon_pat = '(Jan|Fre|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)'

                #-- 正则查找日期，用户，动作段 --# 
                m_pat   = '^\d*[ ]*' + mon_pat + ' [ ]*\d*[ ]*\d+ [ ]*\d+:\d+:\d+ [ ]*[^ ]+ [ ]*kernel:';
                m_ret   = re.match( m_pat, tmp_str);

                #-- 没有匹配到合适的对象，继续下一行 --#
                if m_ret is None:
                    continue;

                #-- 获取动作 --#
                r_index = m_ret.group(0).rfind(' ');
                doit    = m_ret.group(0)[ r_index : -1].strip();

                #-- 获取用户名 --#
                if not m_ret.group(0)[ r_index - 1].isspace() :
                    o_index = r_index;
                    r_index = m_ret.group(0)[0 : o_index].strip().rfind(' ');
                    user    = m_ret.group(0)[ r_index : o_index].strip();
                else :
                    user    = 'None';

                #-- 获取时间 --#
                o_index = r_index;
                r_index = m_ret.group(0)[ 0 : o_index].strip().rfind(' ');
                time    = m_ret.group(0)[ r_index : o_index].strip();

                #-- 获取日期 --#
                o_index = r_index;
                date_list = m_ret.group(0)[ 0 : o_index].strip().split();
                gi   = Gen_Inter();
                date = gi.gi_month_to_numeri( date_list[0]) + '-' + date_list[-1];

                #-- 获取描述信息 --#
                msg = tmp_str[ (len( m_ret.group(0)) + 1) : len( tmp_str)].strip();

                item_dict[ "date"] = date.strip();
                item_dict[ "time"] = time.strip();
                item_dict[ "user"] = user.strip();
                item_dict[ "msg"]  = doit.strip() + ': ' + msg.strip();

                #print item_dict;
                #-- 把字典当作一个元素存放到列表中 --#
                root_list.append( item_dict);

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "kern_log"');

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_kern_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个dpkg日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 dpkg.*log* 的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_dpkg_log( self, path_name):
        '''函数返回值为[{"date":None,"time":None","status":None,
           "pkg":None},{...}]这样的列表
        '''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            for log_line in log_stream:
                item_dict  = {};

                date   = "";    #-- 日期 --#
                time   = "";    #-- 时间 --#
                status = "";    #-- 状态 --#
                pkg    = "";    #-- 安装包 --#

                ok     = 0;     #-- 标志着或一组元素成功 --#
                tmp_str = log_line.strip();

                if len( tmp_str) > 0 :
                    tmp_list = tmp_str.split(" ", 3);

                    #-- 过滤status/configure/startup/trigproc 关键字--#
                    status = str( tmp_list[2]);
                    if status == 'status' or status == 'configure' or \
                       status == 'startup' or status == 'trigproc' :
                        continue;
                    date = str( tmp_list[0]);
                    time = str( tmp_list[1]);
                    pkg  = str( tmp_list[3]).replace('<none>', '');

                    ok   = 1;
                    
                #-- 成功获取一组元素就插入到列表中 --#
                if 1 == ok :
                    item_dict[ "date"]   = date;
                    item_dict[ "time"]   = time;
                    item_dict[ "status"] = status;
                    item_dict[ "pkg"]    = pkg;

                    #-- 把字典当作一个元素存放到列表中 --#
                    root_list.append( item_dict);
                    ok = 0;

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "dpkg_log"');

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_dpkg_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个syslog日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 syslog*的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_sys_log( self, path_name) :
        '''函数返回值为[{"date":None, "time"=None, "user":None",
           "doit":None,"msg":None},{...}]这样的列表
        '''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, 'r');

            for log_line in log_stream:
                item_dict = {};

                date = "";    #-- 日期 --#
                time = "";    #-- 时间 --#
                user = "";    #-- 用户名   --#
                doit = "";    #-- 动作     --#
                msg  = "";    #-- 描述信息 --#

                #-- 临时字符串变量，用户计算上述4个元素项值 --#
                tmp_str = log_line.strip();

                #-- 为空行继续读下一行 --#
                if len( tmp_str) == 0 :
                    continue;

                #-- 月份模式 --#
                mon_pat = '(Jan|Fre|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)'

                #-- 正则查找日期，用户，动作段 --# 
                m_pat   = '^\d*[ ]*' + mon_pat + ' [ ]*\d*[ ]*\d+ [ ]*\d+:\d+:\d+ [ ]*[^ ]+ [ ]*[^:]+:';
                m_ret   = re.match( m_pat, tmp_str);

                #-- 没有匹配到合适的对象，继续下一行 --#
                if m_ret is None :
                    continue;

                #-- 获取动作 --#
                r_index = m_ret.group(0).rfind(' ');
                doit    = m_ret.group(0)[ r_index : -1].strip();

                #-- 获取用户名 --#
                if not m_ret.group(0)[ r_index - 1].isspace() :
                    o_index = r_index;
                    r_index = m_ret.group(0)[0 : o_index].strip().rfind(' ');
                    user    = m_ret.group(0)[ r_index : o_index].strip();
                else :
                    user    = 'None';

                #-- 获取时间 --#
                o_index = r_index;
                r_index = m_ret.group(0)[0 : o_index].strip().rfind(' ');
                time    = m_ret.group(0)[ r_index : o_index].strip();
                
                #-- 获取日期 --#
                o_index = r_index;
                date_list = m_ret.group(0)[ 0 : o_index].strip().split();
                gi   = Gen_Inter();
                date = gi.gi_month_to_numeri( date_list[0]) + '-' + date_list[-1];

                #-- 获取描述信息 --#
                msg = tmp_str[ (len( m_ret.group(0)) + 1) : len( tmp_str)].strip();

                item_dict[ "date"] = date.strip();
                item_dict[ "time"] = time.strip();
                item_dict[ "user"] = user.strip();
                item_dict[ "doit"] = doit.strip();
                item_dict[ "msg"]  = msg.strip();

                #-- 把字典当作一个元素存放到列表中 --#
                root_list.append( item_dict);

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                msg_str = root_list[ i].get( 'msg');
                if msg_str[0] == '[' and msg_str[-1] == ']' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "sys_log"');

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_sys_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个auth日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 auth.*log*的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_auth_log( self, path_name):
        '''函数返回值为[{"date":None, "time"=None, "user":None",
           "doit":None,"msg":None},{...}]这样的列表
        '''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            for log_line in log_stream:
                item_dict  = {};

                date = "";    #-- 日期 --#
                time = "";    #-- 时间 --#
                user = "";    #-- 用户名   --#
                doit = "";    #-- 动作     --#
                msg  = "";    #-- 描述信息 --#

                #-- 临时字符串变量，用户计算上述4个元素项值 --#
                tmp_str = log_line.strip();

                #-- 为空行继续读下一行 --#
                if len( tmp_str) == 0 :
                    continue;

                #-- 月份模式 --#
                mon_pat = '(Jan|Fre|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)'

                #-- 正则查找日期，用户，动作段 --# 
                m_pat   = '^\d*[ ]*' + mon_pat + ' [ ]*\d*[ ]*\d+ [ ]*\d+:\d+:\d+ [ ]*[^ ]+ [ ]*[^:]+:';
                m_ret   = re.match( m_pat, tmp_str);

                #-- 没有匹配到合适的对象，继续下一行 --#
                if m_ret is None:
                    continue;

                #-- 获取动作 --#
                r_index = m_ret.group(0).rfind(' ');
                doit    = m_ret.group(0)[ r_index : -1].strip();

                #-- 获取用户名 --#
                if not m_ret.group(0)[ r_index - 1].isspace():
                    o_index = r_index;
                    r_index = m_ret.group(0)[0 : o_index].strip().rfind(' ');
                    user    = m_ret.group(0)[ r_index : o_index].strip();
                else :
                    user    = 'None';

                #-- 获取时间 --#
                o_index = r_index;
                r_index = m_ret.group(0)[0 : o_index].strip().rfind(' ');
                time    = m_ret.group(0)[ r_index : o_index].strip();
                
                #-- 获取日期 --#
                o_index   = r_index;
                date_list = m_ret.group(0)[ 0 : o_index].strip().split();
                gi   = Gen_Inter();
                date = gi.gi_month_to_numeri( date_list[0]) + '-' + date_list[-1];

                #-- 获取描述信息 --#
                msg = tmp_str[ (len( m_ret.group(0)) + 1) : len( tmp_str)].strip();

                item_dict[ "date"] = date.strip();
                item_dict[ "time"] = time.strip();
                item_dict[ "user"] = user.strip();
                item_dict[ "doit"] = doit.strip();
                item_dict[ "msg"]  = msg.strip();

                #-- 把字典当作一个元素存放到列表中 --#
                root_list.append( item_dict);

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            print 'Error: ' + e.message + ' on "dpkp_log"';
            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_auth_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个alternatives日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 alternatives.*log*的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_alter_log( self, path_name):
        '''函数返回值为[{"date":None,"time":None", "msg":None},{...}]这样的列表'''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            for log_line in log_stream:
                item_dict  = {};

                date   = "";    #-- 日期 --#
                time   = "";    #-- 时间 --#
                msg    = "";    #-- 描述信息 --#

                #-- 为空行继续读下一行 --#
                if len( log_line.strip()) == 0 :
                    continue;

                m_pat  = '^update-alternatives';
                m_ret  = re.match( m_pat, log_line);

                #-- 匹配成功，则获取元素数据 --#
                if m_ret is not None :
                    tmp_list = log_line.split(" ", 3);
                    date = str( tmp_list[1]);
                    time = str( tmp_list[2])[ : -1];
                    msg  = str( tmp_list[3]);

                    #-- 成功获取一组元素就插入到列表中 --#
                    item_dict[ "date"]   = date;
                    item_dict[ "time"]   = time;
                    item_dict[ "msg"]    = msg.strip();

                    #-- 把字典当作一个元素存放到列表中 --#
                    root_list.append( item_dict);

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "alter_log"');

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_alter_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个ufw日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 ufw.log*的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_ufw_log( self, path_name) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, user, incard, outcard, mac, src, dest, len, --#
        #-- id, proto, spt, dpt, window                              --#

        root_list = [];
        log_file  = path_name;
    
        try :
            #-- 月份匹配模式 --#
            mon_pat = '(Jan|Fre|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)'

            #-- 查找时间段的正则字串 --#
            m_pat   = '^\d*[ ]*' + mon_pat + ' [ ]*\d*[ ]*\d+ [ ]*\d+:\d+:\d+';

            log_stream = open( log_file, 'r');
            for log_line in log_stream :
                item_dict = {'date':None, 'time':None, 'user':None, 'incard':None, 
                             'outcard':None, 'mac':None, 'src':None, 'dest':None, 
                             'len':None, 'id':None, 'proto':None, 'spt':None, 
                             'dpt':None, 'window':None};

                #-- 使用临时变量来操作行数据 --#
                tmp_str = log_line.strip();
                
                #-- 为空行继续读下一行 --#
                if len( tmp_str) == 0 :
                    continue;

                #-- 获取date数据，必须有，如果没有则不是正确的日志行 --#
                m_ret = re.match( m_pat, tmp_str);
                if m_ret is not None :
                    #-- 获取时间 --#
                    r_index = m_ret.group(0).rfind(' ');
                    item_dict[ 'time'] = m_ret.group(0)[ r_index : ].strip();

                    #-- 获取日期 --#
                    date_list = m_ret.group(0)[ 0 : r_index].strip().split();
                    gi   = Gen_Inter();
                    date = gi.gi_month_to_numeri( date_list[0]) + '-' + date_list[-1];
                    item_dict[ 'date'] = date;

                    #-- 分割行字串，获取对应的值 --#
                    sub_str  = tmp_str[ len( m_ret.group(0)) : ].strip();
                    tmp_list = sub_str.split();
                    
                    #-- 获取用户名 --#
                    item_dict[ 'user'] = tmp_list[0];

                    tmp_list.pop(0);

                    while len( tmp_list) :
                        tmp_list_item = str( tmp_list.pop()).strip();

                        #-- 获取WINDOW的value --#
                        if 'WINDOW=' == tmp_list_item[ 0 : 7] :
                            item_dict[ 'window'] = tmp_list_item[ 7 : ].strip();

                        #-- 获取DPT的value --#
                        if 'DPT=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'dpt'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取SPT的value --#
                        if 'SPT=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'spt'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取PROTO的value --#
                        if 'PROTO=' == tmp_list_item[ 0 : 6] :
                            item_dict[ 'proto'] = tmp_list_item[ 6 : ].strip();

                        #-- 获取ID的value --#
                        if 'ID=' == tmp_list_item[ 0 : 3] :
                            item_dict[ 'id'] = tmp_list_item[ 3 : ].strip();

                        #-- 获取DPT的value --#
                        if 'LEN=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'len'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取DEST的value --#
                        if 'DST=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'dest'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取DPT的value --#
                        if 'SRC=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'src'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取SPT的value --#
                        if 'MAC=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'mac'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取DPT的value --#
                        if 'OUT=' == tmp_list_item[ 0 : 4] :
                            item_dict[ 'outcard'] = tmp_list_item[ 4 : ].strip();

                        #-- 获取SPT的value --#
                        if 'IN=' == tmp_list_item[ 0 : 3] :
                            item_dict[ 'incard'] = tmp_list_item[ 3 : ].strip();
                    #-- END WHILE len( tmp_list) --#

                    root_list.append( item_dict);

            #-- 记得关闭打开的文件描述符 --#
            log_stream.close();

        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "ufw_log"');  

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_ufw_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个ufw日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 ufw.log*的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_cups_log( self, path_name) :
        '''返回值为[{'date':, 'time':, 'host':, 'user':, 'doit':, 'msg':},
           {...},...]列表
        '''
        root_list = [];
        log_file  = path_name;
        conv_mon  = {'Jan':'1', 'Feb':'2', 'Mar':'3', 'Apr':'4', 'May':'5', 'Jun':'6',
                     'Jul':'7', 'Aug':'8', 'Sep':'9', 'Oct':'10', 'Nov':'11', 'Dec':'12'
                    };

        try :
            log_stream = open( log_file, 'r');

            for log_line in log_stream :
                if len( log_line.strip()) :
                    item_dict = {};

                    #-- 双引号之间的执行的动作 --#
                    l_quot = log_line.find('"');
                    r_quot = log_line.rfind('"');

                    item_dict['doit'] = log_line[ (l_quot + 1) : r_quot];
                    item_dict['msg' ] = log_line[ (r_quot + 1) : ].strip();

                    #-- 获取执行的动作前面部分的字符 --#
                    prev_str = log_line[ 0 : (l_quot - 1)].strip();

                    #-- 以空格拆分，获取对应的项 --#
                    split_prev = prev_str.split();
                    item_dict['host'] = split_prev[0];
                    item_dict['user'] = split_prev[2];

                    #-- 分割时间，第三个元素为日期时间的结合体 --#
                    date_time = str( split_prev[3]).strip()[ 1 : ];
                    l_colon   = date_time.find(':');
                    date_list = date_time[ 0 : l_colon].split('/');
                    date_str  = date_list[2] + '-' + conv_mon.get( date_list[1]) + '-' + date_list[0];
                    print date_str;

                    #item_dict['date'] = date_time[ 0 : l_colon].replace('/', '-');
                    item_dict['date'] = date_str;
                    item_dict['time'] = date_time[ (l_colon + 1) : ];

                    root_list.append( item_dict);

            #-- 记得要关闭打开的文件描述符 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "cups_log"');  

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_cups_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个dmesg日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为 dmesg 的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_dmesg_log( self, path_name) :
        '''返回值为[{"loadt":None, "msg":None},{...}]列表'''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            #-- 匹配加载时间的模式 --#
            m_pat = '^\[[ ]*\d+\.\d+\]';

            #-- 逐行获取并解析 --#
            for log_line in log_stream:
                item_dict = {};
                tmp_str   = log_line.strip();

                #-- 不为空行 --#
                if len( tmp_str) > 0 :
                    m_ret = re.match( m_pat, tmp_str);

                    #-- 匹配到加载时间，则新添加列表元素 --#
                    if m_ret is not None :
                        r_bracket = tmp_str.find(']');
                        if r_bracket > 0 :
                            item_dict[ 'loadt'] = tmp_str[ 1 : r_bracket ].strip();
                            item_dict[ 'msg'  ] = tmp_str[ (r_bracket + 1) : ].strip();

                            #-- 添加到加载信息列表集合中去 --#
                            root_list.append( item_dict);
                    else :
                        list_size = len( root_list);
                        if list_size > 0 :
                            tmp_msg = root_list[ list_size - 1].get('msg');
                            root_list[ list_size -1][ 'msg'] = tmp_msg + ' ' + tmp_str;


            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "dmesg_log"');  

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_dmesg_log --#


    #----------------------------------------------------------------#
    #-@brief: 解析单个/var/log/Xorg.0.log日志文件的静态方法，仅供内部使用.
    #-
    #-@param: path_name 为/var/log/Xorg.0.log 的日志文件.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    @staticmethod
    def parser_sgl_xorg_log( self, path_name) :
        '''返回值为[{"loadt":None, "msg":None},{...}]列表'''
        root_list = [];

        try:
            log_file   = path_name;
            log_stream = open( log_file, "r");

            #-- 匹配加载时间的模式 --#
            m_pat = '^\[[ ]*\d+\.\d+\]';

            #-- 逐行获取并解析 --#
            for log_line in log_stream:
                item_dict = {};
                tmp_str   = log_line.strip();

                #-- 不为空行 --#
                if len( tmp_str) > 0 :
                    m_ret = re.match( m_pat, tmp_str);

                    #-- 匹配到加载时间，则新添加列表元素 --#
                    if m_ret is not None :
                        r_bracket = tmp_str.find(']');
                        if r_bracket > 0 :
                            item_dict[ 'loadt'] = tmp_str[ 1 : r_bracket ].strip();
                            item_dict[ 'msg'  ] = tmp_str[ (r_bracket + 1) : ].strip();

                            #-- 添加到加载信息列表集合中去 --#
                            root_list.append( item_dict);
                    else :
                        list_size = len( root_list);
                        if list_size > 0 :
                            tmp_msg = root_list[ list_size - 1].get('msg');
                            root_list[ list_size -1][ 'msg'] = tmp_msg + ' ' + tmp_str;

            #-- 一定要记得关闭字符串，否则造成资源一直被占用 --#
            log_stream.close();

            i = 0;
            #-- msg为空的时候移除出列表元素 --#
            while ( i < len( root_list)) :
                if root_list[ i].get( 'msg').strip() == '' :
                    root_list.pop( i);
                else : 
                    i = i + 1;

        #-- 异常情况，主要是为了检测打开的文件不存在而写 --#
        except Exception, e:
            gi = Gen_Inter();
            gi.gi_lpmt_error_log( 'Error: ' + e.message + ' on "xorg_log"');  

            #-- 清除root_list列表，以免还有错误值返回 --#
            while len( root_list) :
                root_list.pop();

        return root_list;
    #-- END OF FUNCTION: parser_sgl_xorg_log --#
    

    #----------------------------------------------------------------#
    #-@brief: 自动解析多个boot日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_boot_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- doit, msg --#

        bootlog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取boot.开头的日志文件列表 --#
        boot_logs = gi_case.gi_search_same_f( '^boot\.'); 

        #-- 挨个获取日志信息 --#
        while len( boot_logs) :
            gz_flag     = 0;
            log_file    = str( boot_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个boot.log的日志 --#
                ret_list = self.parser_sgl_boot_log( self, un_log_file);
                if len( ret_list) :
                    bootlog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return bootlog_list;
    #-- END OF FUNCTION: parser_all_boot_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个kern日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_kern_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, user, msg --#

        kernlog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取kern.开头的日志文件列表 --#
        kern_logs = gi_case.gi_search_same_f( '^kern\.'); 

        #-- 挨个获取日志信息 --#
        while len( kern_logs) :
            gz_flag     = 0;
            log_file    = str( kern_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个kern.log的日志 --#
                ret_list = self.parser_sgl_kern_log( self, un_log_file);
                if len( ret_list) :
                    kernlog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return kernlog_list;
    #-- END OF FUNCTION: parser_all_kern_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个dpkg日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_dpkg_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, status, pkg --#

        dpkglog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取dpkg.开头的日志文件列表 --#
        dpkg_logs = gi_case.gi_search_same_f( '^dpkg\.'); 

        #-- 挨个获取日志信息 --#
        while len( dpkg_logs) :
            gz_flag     = 0;
            log_file    = str( dpkg_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个dpkg.log的日志 --#
                ret_list = self.parser_sgl_dpkg_log( self, un_log_file);
                if len( ret_list) :
                    dpkglog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return dpkglog_list;
    #-- END OF FUNCTION: parser_all_dpkg_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个syslog日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_sys_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, user, doit, msg --#

        syslog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取syslog开头的日志文件列表 --#
        sys_logs = gi_case.gi_search_same_f( '^syslog'); 

        #-- 挨个获取日志信息 --#
        while len( sys_logs) :
            gz_flag     = 0;
            log_file    = str( sys_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个syslog的日志 --#
                ret_list = self.parser_sgl_sys_log( self, un_log_file);
                if len( ret_list) :
                    syslog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return syslog_list;
    #-- END OF FUNCTION: parser_all_sys_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个auth日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_auth_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, user, doit, msg --#

        authlog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取auth.开头的日志文件列表 --#
        auth_logs = gi_case.gi_search_same_f( '^auth\.'); 

        #-- 挨个获取日志信息 --#
        while len( auth_logs) :
            gz_flag     = 0;
            log_file    = str( auth_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个auth.log的日志 --#
                ret_list = self.parser_sgl_auth_log( self, un_log_file);
                if len( ret_list) :
                    authlog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return authlog_list;
    #-- END OF FUNCTION: parser_all_auth_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个alternatives日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_alter_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, msg --#

        alterlog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取alternatives开头的日志文件列表 --#
        alter_logs = gi_case.gi_search_same_f( '^alternatives\.'); 

        #-- 挨个获取日志信息 --#
        while len( alter_logs) :
            gz_flag     = 0;
            log_file    = str( alter_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个alter.log的日志 --#
                ret_list = self.parser_sgl_alter_log( self, un_log_file);
                if len( ret_list) :
                    alterlog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return alterlog_list;
    #-- END OF FUNCTION: parser_all_alter_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个ufw日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_ufw_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, user, incard, outcard, mac, src, dest, dlen, --#
        #-- tos, prec, ttl, id, proto, spt, dpt                      --#;

        ufwlog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取ufw.开头的日志文件列表 --#
        ufw_logs = gi_case.gi_search_same_f( '^ufw\.'); 

        #-- 挨个获取日志信息 --#
        while len( ufw_logs) :
            gz_flag     = 0;
            log_file    = str( ufw_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个ufw.log的日志 --#
                ret_list = self.parser_sgl_ufw_log( self, un_log_file);
                if len( ret_list) :
                    ufwlog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return ufwlog_list;
    #-- END OF FUNCTION: parser_all_ufw_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析多个cups/access_log日志文件的全局方法.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_cups_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- date, time, host, user, doit, msg  --#

        cupslog_list = [];

        gi_case  = Gen_Inter();

        #-- 获取access_log开头的日志文件列表 --#
        cups_logs = gi_case.gi_search_same_f( pat='^access_log', d_path='/var/log/cups/'); 

        #-- 挨个获取日志信息 --#
        while len( cups_logs) :
            gz_flag     = 0;
            log_file    = str( cups_logs.pop()).strip();
            un_log_file = "";
            ret_list    = [];

            #-- 如果是gz后缀的文件 --#
            if '.gz' == log_file[ -3 : ] :
                un_log_file = gi_case.gi_uncompress_gz( log_file);
                gz_flag = 1;
            else :
                un_log_file = log_file;

            #-- 日志文件存在，主要检测解压时是否成功了 --#
            if len( un_log_file) :
                #-- 获取一个cups/access_log的日志 --#
                ret_list = self.parser_sgl_cups_log( self, un_log_file);
                if len( ret_list) :
                    cupslog_list.extend( ret_list);

                #-- 删除临时文件 --#
                if gz_flag :
                    os.remove( un_log_file);

        return cupslog_list;
    #-- END OF FUNCTION: parser_all_cups_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析/var/log/dmesg日志文件的全局方法, 因为该日志文件
    #-        没有明确的时间分割，所以只读取它来做分析.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_dmesg_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- loadt, msg  --#

        dmesglog_list = [];
        dmesg_path = '/var/log/dmesg';

        #-- 确定/var/log/dmesg文件是否存在 --#
        if os.path.exists( dmesg_path) :
            dmesglog_list = self.parser_sgl_dmesg_log( self, dmesg_path);

        return dmesglog_list;
    #-- END OF FUNCTION: parser_all_dmesg_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析/var/log/Xorg.0.log日志文件的全局方法, 因为该日志
    #-        文件没有明确的时间分割，所以只读取它来做分析.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_xorg_log( self) :
        #--返回值为[{},{...},...]集合的列表    --#
        #--列表元素为字典，字典包含以下key名称 --#
        #-- loadt, msg  --#

        dmesglog_list = [];
        dmesg_path = '/var/log/Xorg.0.log';

        #-- 确定/var/log/Xorg.0.log文件是否存在 --#
        if os.path.exists( dmesg_path) :
            dmesglog_list = self.parser_sgl_xorg_log( self, dmesg_path);

        return dmesglog_list;
    #-- END OF FUNCTION: parser_all_xorg_log --#


    #----------------------------------------------------------------#
    #-@brief: 自动解析/var/log/faillog日志文件的全局方法, 因为该日志
    #-        文件为二进制文件，所以通过faillog -a 命令来获取.
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def parser_all_fail_log( self) :
        #-- 返回值为[{},{...},...]的列表，元素为字典，字典中的数据 --#
        #-- 项的key为 user, ftimes, date, time --#
        faillog_list = [];

        try :
            fail_stream = os.popen( 'faillog -a');
            fail_stream.readline();

            #-- 上面是去掉第一行，因为第一行为标题行 --#
            for line in fail_stream :
                #-- 去除空格，看看是否是空行 --#
                line = line.strip();
                if len( line) == 0 :
                    continue;
                line_list = line.split();

                #-- 日期格式为2014-01-01这样 --#
                date      = "";
                date_list = line_list[3].split('/');
                if len( date_list[2]) == 2 :
                    gi_case  = Gen_Inter();

                    #-- 获取本地时间的年份 --#
                    year = gi_case.gi_get_year();

                    if int( date_list[2]) > 69 :
                        date = '19' + date_list[2] + '-' + date_list[1] + '-' + date_list[0];
                    else :
                        date = year[0 : 2] + date_list[2] + '-' + date_list[1] + '-' + date_list[0];

                #-- 构造字典元素 --#
                item_dict = {};
                item_dict[ 'user']   = line_list[0];
                item_dict[ 'ftimes'] = line_list[1];

                #-- 如果用户失败登录次数为0，则没有日期时间显示 --#
                if int( line_list[1]) == 0 :
                    item_dict[ 'date'] = '';
                    item_dict[ 'time'] = '';
                else :
                    item_dict[ 'date']   = date;
                    item_dict[ 'time']   = line_list[4];

                #-- 把得到的元素插入到列表中 --#
                faillog_list.append( item_dict);
            
            #-- 关闭管道流 --#
            fail_stream.close();

        except Exception, e:
            #-- 清除faillog_list列表，以免还有错误值返回 --#
            while len( faillog_list) :
                faillog_list.pop();

        return faillog_list;
    #-- END OF FUNCTION: parser_all_fail_log --#
            

#--------------------------------- main -----------------------------#
#if __name__ == '__main__' :
#    ufw_log = Parser_LPMT();
#    ret_list = ufw_log.parser_all_boot_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_kern_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_dpkg_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_sys_log(); 
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_auth_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_alter_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_ufw_log(); 
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_cups_log(); 
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_dmesg_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_xorg_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = ufw_log.parser_all_fail_log();
#
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#
